@@ -25,7 +25,7 @@ class Deck:
 		l = ['+' + t for t in self.tags_include]
 		l += ['-' + t for t in self.tags_exclude]
 		l += ['=' + t for t in self.tags_create]
-		return self.name + '\t' + ' '.join(l)
+		return f'{self.name:16s}' + ' '.join(l)
 
 class Card:
 	def __init__(self, cid=None, create=False):
@@ -196,8 +196,9 @@ class Decklist(dict):
 		return dict.__len__(self) // 2
 
 	def delete(self, deck):
-		del_idx = deck.idx
-		l = [str(self[i]) for i in range(len(self)) if i != del_idx]
+		del self[deck.name]
+		del self[deck.idx]
+		l = [str(d) for d in set(self.values())]
 		decks_file.write_text('\n'.join(l))
 
 
