@@ -112,7 +112,7 @@ def statistics(args):
 def edit(args):
 	if args.cards:
 		for card in args.cards:
-			args.card.edit()
+			card.edit()
 		return
 	vim_cmd = ['vim',decks_path] 
 	vim_cmd += [f'+{args.decks[0].idx + 1}'] if args.decks else []
@@ -151,8 +151,7 @@ def visual_decks(args):
 			if i == selected:
 				run(['tput','smso'])
 			print(decklist[i])
-			if i == selected:
-				run(['tput','sgr0'])
+			run(['tput','sgr0'])
 		#get key
 		k = readchar.readchar()
 		if k == 'j' and selected < n - 1:
@@ -198,9 +197,10 @@ def visual_query(args):
 		for i,(card,hit) in enumerate(matches):
 			if i == selected:
 				run(['tput','smso']) # standout attribute
+			if card.deletedQ:
+				run(['tput','dim'])
 			print(f'{hit[:50]}')
-			if i == selected:
-				run(['tput','sgr0']) # normal attribute
+			run(['tput','sgr0']) # normal attribute
 		#get key
 		k = readchar.readchar()
 		if k == 'j' and selected < n - 1:
@@ -212,14 +212,15 @@ def visual_query(args):
 			exit(0)
 			break
 		if k in arg_dict.keys():
-			for i in range(n):
-				run(['tput','cuu1']) # move up n lines
-				run(['tput','el']) # and clear them as we go
-			run(['tput','cvvis'])
-			args.card = matches[selected][0]
+			# for i in range(n):
+			# 	run(['tput','cuu1']) # move up n lines
+			# 	run(['tput','el']) # and clear them as we go
+			#run(['tput','cvvis'])
+			args.cards = [matches[selected][0]]
 			cmd = arg_dict[k]
 			cmd(args)
-			break
+			run(['tput','civis'])
+			#break
 
 def purge(args):
 	for card in col:
